"""Module for the command list inside the group scan.
This module takes care of listing all the remote or local scans.
Example of usage:
    - ostorlab scan list --source=source."""

import click

from ostorlab.cli import console as cli_console
from ostorlab.cli.scan import scan

console = cli_console.Console()


def _style_risk(risk: str) -> str:
    """Stylize the risk with colors."""
    if risk == 'HIGH':
        return '[bold red]High[/]'
    elif risk == 'MEDIUM':
        return '[bold yellow]Medium[/]'
    elif risk == 'LOW':
        return '[bold bright_yellow]Low[/]'
    else:
        return risk


def _style_progress(progress: str) -> str:
    """Stylize the scan progress with colors."""
    if progress == 'done':
        return '[bold green4]Done[/]'
    if progress == 'error':
        return '[bold magenta]Error[/]'
    if progress == 'not_started':
        return '[bold bright_black]Not Started[/]'
    if progress == 'stopped':
        return '[bold bright_red]Stopped[/]'
    if progress == 'in_progress':
        return '[bold bright_cyan]Running[/]'
    else:
        return progress


def _style_asset(asset: str) -> str:
    """Stylize the scan asset with colors and emojis."""
    if asset == 'android_store':
        return '[bold green4]:iphone: Android Store[/]'
    elif asset == 'ios_store':
        return '[bold bright_white]:apple: iOS Store[/]'
    elif asset == 'android':
        return '[bold bright_green]:iphone: Android[/]'
    elif asset == 'ios':
        return '[bold white]:apple: iOS[/]'
    else:
        return asset


@scan.command(name='list')
@click.option('--page', '-p', help='Page number of scans you would like to see.', default=1)
@click.option('--elements', '-e', help='Number of scans to show per page.', default=10)
@click.pass_context
def list_scans(ctx: click.core.Context, page: int, elements: int) -> None:
    """List all your scans.\n
    Usage:\n
        - ostorlab scan list --source=source
    """
    runtime_instance = ctx.obj['runtime']
    with console.status('Fetching scans'):
        scans = runtime_instance.list(page=page, number_elements=elements)
        if scans is not None:
            console.success('Scans listed successfully.')
            columns = {'Id': 'id',
                       'Application': 'application',
                       'Platform': 'platform',
                       'Plan': 'plan',
                       'Created Time': 'created_time',
                       'Progress': 'progress',
                       'Risk': 'risk'}
            title = f'Showing {len(scans)} Scans'

            data = [
                {
                    'id': s.id,
                    'application': f'{s.application or ""}: {s.version or ""}',
                    'platform': _style_asset(s.platform),
                    'plan': s.plan,
                    'created_time': s.created_time,
                    'progress': _style_progress(s.progress),
                    'risk': _style_risk(s.risk),
                } for s in scans]

            console.table(columns=columns, data=data, title=title)
        else:
            console.error('Error fetching scan list.')



"""Auth revoke command."""

import logging

from ostorlab.apis import runner as apis_runner
from ostorlab.apis import revoke_api_key
from ostorlab import configuration_manager
from ostorlab.cli.auth import auth
from ostorlab.cli import console as cli_console

logger = logging.getLogger(__name__)
console = cli_console.Console()


@auth.auth.command()
def revoke():
    """Use this to revoke your API key."""

    config_manager = configuration_manager.ConfigurationManager()

    try:
        api_key_id = config_manager.get_api_key_id()
        runner = apis_runner.APIRunner()

        with console.status('Revoking API key'):
            response = runner.execute(revoke_api_key.RevokeAPIKeyAPIRequest(api_key_id))
            if response.get('errors') is not None:
                console.error('Could not revoke your API key.')

            runner.unauthenticate()
            config_manager.delete_api_data()
            console.success('API key revoked')
    except apis_runner.AuthenticationError:
        runner.unauthenticate()
        console.success('Your API key has already been revoked.')



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/report/event/vulnerability/vulnerability.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/report/event/vulnerability/vulnerability.proto',
  package='v3.report.event.vulnerability',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n1v3/report/event/vulnerability/vulnerability.proto\x12\x1dv3.report.event.vulnerability\"r\n\x07Message\x12\r\n\x05title\x18\x01 \x02(\t\x12\x18\n\x10technical_detail\x18\x02 \x02(\t\x12>\n\x0brisk_rating\x18\x03 \x02(\x0e\x32).v3.report.event.vulnerability.RiskRating*p\n\nRiskRating\x12\x08\n\x04HIGH\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x07\n\x03LOW\x10\x02\x12\x0f\n\x0bPOTENTIALLY\x10\x03\x12\r\n\tHARDENING\x10\x04\x12\n\n\x06SECURE\x10\x05\x12\r\n\tIMPORTANT\x10\x06\x12\x08\n\x04INFO\x10\x07')
)

_RISKRATING = _descriptor.EnumDescriptor(
  name='RiskRating',
  full_name='v3.report.event.vulnerability.RiskRating',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POTENTIALLY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HARDENING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECURE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORTANT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=200,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_RISKRATING)

RiskRating = enum_type_wrapper.EnumTypeWrapper(_RISKRATING)
HIGH = 0
MEDIUM = 1
LOW = 2
POTENTIALLY = 3
HARDENING = 4
SECURE = 5
IMPORTANT = 6
INFO = 7



_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.report.event.vulnerability.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='v3.report.event.vulnerability.Message.title', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technical_detail', full_name='v3.report.event.vulnerability.Message.technical_detail', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='risk_rating', full_name='v3.report.event.vulnerability.Message.risk_rating', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=198,
)

_MESSAGE.fields_by_name['risk_rating'].enum_type = _RISKRATING
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.enum_types_by_name['RiskRating'] = _RISKRATING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'v3.report.event.vulnerability.vulnerability_pb2'
  # @@protoc_insertion_point(class_scope:v3.report.event.vulnerability.Message)
  ))
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v3/report/event/scan/done/done.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='v3/report/event/scan/done/done.proto',
  package='v3.report.event.scan.done',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n$v3/report/event/scan/done/done.proto\x12\x19v3.report.event.scan.done\"\t\n\x07Message')
)




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='v3.report.event.scan.done.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=76,
)

DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'v3.report.event.scan.done.done_pb2'
  # @@protoc_insertion_point(class_scope:v3.report.event.scan.done.Message)
  ))
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)
